@@ -46,15 +46,13 @@
 #include <QLayout>
 #include <QVBoxLayout>
 
-namespace KPIM {
+using namespace KPIM;
 static const int MAX_LABEL_WIDTH = 650;
 
-class TransactionItem;
-
-TransactionItemView::TransactionItemView(QWidget *parent, const char *name)
+TransactionItemView::TransactionItemView(QWidget *parent, const QString &name)
     : QScrollArea(parent)
 {
-    setObjectName(QLatin1String(name));
+    setObjectName(name);
     setFrameStyle(NoFrame);
     mBigBox = new QWidget(this);
     QVBoxLayout *mBigBoxVBoxLayout = new QVBoxLayout(mBigBox);
@@ -138,10 +136,9 @@ TransactionItem::TransactionItem(QWidget *parent, ProgressItem *item, bool first
     , mCancelButton(nullptr)
     , mItem(item)
 {
-    QVBoxLayout *vboxLayout = new QVBoxLayout;
+    QVBoxLayout *vboxLayout = new QVBoxLayout(this);
     vboxLayout->setSpacing(2);
     vboxLayout->setMargin(2);
-    setLayout(vboxLayout);
     setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
 
     mFrame = new QFrame(this);
@@ -198,7 +195,7 @@ TransactionItem::TransactionItem(QWidget *parent, ProgressItem *item, bool first
     }
 }
 
-TransactionItem::~TransactionItem()
+KPIM::TransactionItem::~TransactionItem()
 {
 }
 
@@ -259,14 +256,18 @@ void TransactionItem::addSubTransaction(ProgressItem *item)
 
 ProgressDialog::ProgressDialog(QWidget *alignWidget, QWidget *parent)
     : OverlayWidget(alignWidget, parent)
-    , mShowTypeProgressItem(0)
-    , mWasLastShown(false)
 {
-    setFrameStyle(QFrame::Panel | QFrame::Sunken);   // QFrame
+    // Qt Bug: Sunken is not applied for RTL layouts correctly (is not mirrored).
+    // For now let's just use Plain, which is fine for this.
+    if (layoutDirection() == Qt::LeftToRight) {
+        setFrameStyle(QFrame::Panel | QFrame::Sunken);   // QFrame
+    } else {
+        setFrameStyle(QFrame::Panel | QFrame::Plain);    // QFrame
+    }
 
     setAutoFillBackground(true);
 
-    mScrollView = new TransactionItemView(this, "ProgressScrollView");
+    mScrollView = new TransactionItemView(this, QStringLiteral("ProgressScrollView"));
     layout()->addWidget(mScrollView);
     /*
     * Get the singleton ProgressManager item which will inform us of
@@ -297,6 +298,11 @@ void ProgressDialog::closeEvent(QCloseEvent *e)
     hide();
 }
 
+bool ProgressDialog::wasLastShown() const
+{
+    return mWasLastShown;
+}
+
 /*
  *  Destructor
  */
@@ -314,8 +320,7 @@ void ProgressDialog::slotTransactionAdded(ProgressItem *item)
 {
     if (item->typeProgressItem() == mShowTypeProgressItem) {
         if (item->parent()) {
-            if (mTransactionsToListviewItems.contains(item->parent())) {
-                TransactionItem *parent = mTransactionsToListviewItems[ item->parent() ];
+            if (TransactionItem *parent = mTransactionsToListviewItems.value(item->parent())) {
                 parent->addSubTransaction(item);
             }
         } else {
@@ -333,8 +338,7 @@ void ProgressDialog::slotTransactionAdded(ProgressItem *item)
 
 void ProgressDialog::slotTransactionCompleted(ProgressItem *item)
 {
-    if (mTransactionsToListviewItems.contains(item)) {
-        TransactionItem *ti = mTransactionsToListviewItems[ item ];
+    if (TransactionItem *ti = mTransactionsToListviewItems.value(item)) {
         mTransactionsToListviewItems.remove(item);
         ti->setItemComplete();
         QTimer::singleShot(3000, ti, &QObject::deleteLater);
@@ -428,4 +432,3 @@ void ProgressDialog::slotToggleVisibility()
         setVisible(isHidden());
     }
 }
-}
