@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+    Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -22,8 +22,8 @@
 
 #include <QHBoxLayout>
 
-namespace KPIM {
-class ProgressIndicatorLabelPrivate
+using namespace KPIM;
+class KPIM::ProgressIndicatorLabelPrivate
 {
 public:
     ProgressIndicatorLabelPrivate(const QString &_label, ProgressIndicatorLabel *qq)
@@ -63,8 +63,8 @@ public:
     }
 
     QString labelStr;
-    QLabel *label;
-    ProgressIndicatorWidget *indicator;
+    QLabel *label = nullptr;
+    ProgressIndicatorWidget *indicator = nullptr;
     ProgressIndicatorLabel *q;
 };
 
@@ -99,4 +99,3 @@ void ProgressIndicatorLabel::setActiveLabel(const QString &label)
 {
     d->setActiveLabel(label);
 }
-}
