@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,6 +20,8 @@
 #ifndef ADDRESSEELINEEDITBALOO_H
 #define ADDRESSEELINEEDITBALOO_H
 
+#include <QStringList>
+
 namespace KPIM {
 class AddresseeLineEditManager;
 class AddresseeLineEditBaloo
@@ -31,9 +33,17 @@ public:
     int balooCompletionSource() const;
     void setBalooCompletionSource(int value);
 
+    QStringList balooBlackList() const;
+    QStringList domainExcludeList() const;
+
+    void loadBalooBlackList();
+    QStringList cleanupEmailList(const QStringList &inputList);
 private:
-    int mBalooCompletionSource;
-    AddresseeLineEditManager *mAddressLineStatic;
+    QStringList mBalooBlackList;
+    QStringList mDomainExcludeList;
+
+    int mBalooCompletionSource = 0;
+    AddresseeLineEditManager *mAddressLineStatic = nullptr;
 };
 }
 
