@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,18 +17,22 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #include "addressesslineeditabstractplugin.h"
 
 using namespace KPIM;
 
 AddressessLineEditAbstractPlugin::AddressessLineEditAbstractPlugin(QObject *parent)
     : QObject(parent)
+    , mLinedit(nullptr)
+    , mEnabled(true)
 {
-
 }
 
 AddressessLineEditAbstractPlugin::~AddressessLineEditAbstractPlugin()
 {
+}
 
+void AddressessLineEditAbstractPlugin::setLineEdit(AddresseeLineEdit *linedit)
+{
+    mLinedit = linedit;
 }
