@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,6 +24,14 @@
 #include "kdepimakonadi_export.h"
 
 namespace KPIM {
+class AddresseeLineEdit;
+struct KDEPIMAKONADI_EXPORT AddressessLineEditAbstractPluginInfo
+{
+    QString name;
+    QString identifier;
+    QString description;
+};
+
 class KDEPIMAKONADI_EXPORT AddressessLineEditAbstractPlugin : public QObject
 {
     Q_OBJECT
@@ -31,10 +39,19 @@ public:
     explicit AddressessLineEditAbstractPlugin(QObject *parent = nullptr);
     ~AddressessLineEditAbstractPlugin();
 
-    virtual QString identifier() const = 0;
+    void setLineEdit(KPIM::AddresseeLineEdit *linedit);
+
+    virtual QVector<AddressessLineEditAbstractPluginInfo> names() const = 0;
+    virtual void start() = 0;
+    virtual void cancel() = 0;
+    virtual void stop() = 0;
 
 Q_SIGNALS:
     void wasUpdated();
+
+private:
+    KPIM::AddresseeLineEdit *mLinedit = nullptr;
+    bool mEnabled = false;
 };
 }
 
